// src/index.ts
import { nanoid } from "nanoid";

// src/helpers/encryption.ts
import StringCrypto from "string-crypto";
var Encryptor = class {
  constructor(password) {
    this.cryptor = new StringCrypto();
    this.password = password;
  }
  encryptString(str) {
    return this.cryptor.encryptString(str, this.password);
  }
  decryptString(str) {
    return this.cryptor.decryptString(str, this.password);
  }
};

// src/helpers/redis.ts
import Keyv from "@keyvhq/core";
import KeyvRedis from "@keyvhq/redis";
function createRedisClient(redisConfig, namespace) {
  const cache = new KeyvRedis(redisConfig.url, {
    password: redisConfig.password,
    db: redisConfig.db ?? 0
  });
  return new Keyv({
    store: cache,
    namespace
  });
}

// src/index.ts
var EphemeralStore = class {
  constructor(options) {
    this.redisClient = createRedisClient({
      url: options.redis.url,
      password: options.redis.password,
      db: options.redis.db
    }, options.namespace);
    this.ttl = options.expirationMs;
    this.encryptor = new Encryptor(options.encryptionPassword ?? "");
    this.idLength = options.idLength;
  }
  async save(value, customId) {
    const id = customId ?? nanoid(this.idLength);
    await this.redisClient.set(id, this.encryptor.encryptString(value), this.ttl);
    return id;
  }
  async get(id) {
    const stored = await this.redisClient.get(id);
    return this.encryptor.decryptString(stored);
  }
};
export {
  EphemeralStore
};
